<?php

/**
 * Zip functions
 *
 * @package    Sitelock
 * @subpackage Sitelock/admin
 * @author     Todd Low <tlow@sitelock.com>
 */
class Sitelock_Zip {

    /**
     * ZIP folder
     *
     * @since    2.0.0
     * @access   public
     */
    public $zip_folder;

    /**
     * The location for our zip files used by SMART
     *
     * @since    2.0.0
     * @access   public
     */
    public $zip_location;
    
    
    /**
     * Encryption key for zip files
     *
     * @since   2.0.0
     * @access  public
     */
    public $encrypt_key;
    
    
    /**
     * mcrypt_encrypt cipher
     *
     * @since   2.0.0
     * @access  public
     */
    public $cipher;
    
    
    /**
     * mcrypt_encrypt mode
     *
     * @since   2.0.0
     * @access  public
     */
    public $mode;
    
    
    /**
     * mcrypt_encrypt iv
     *
     * @since   2.0.0
     * @access  public
     */
    public $iv;
    

    
    /**
     * Initialize the class and set its properties.
     *
     * @since    2.0.0
     */
    public function __construct() {

        $this->zip_folder     = 'smart_zips';
        $this->zip_location   = str_replace( '/admin', '', plugin_dir_path( __FILE__ ) ) . $this->zip_folder;
        $this->encrypt_key    = '';        # updated by Sitelock_Admin->smart_run();
        $this->cipher         = MCRYPT_BLOWFISH;     # updated by Sitelock_Admin->smart_run();
        $this->mode           = MCRYPT_MODE_CBC;
        $this->iv             = "12345678";  # updated by Sitelock_Admin->smart_run();
        $this->new_zip_size   = 0;
        $this->num_files = 0;
        
    }
    
    
    /**
     * Get the file size of the new zip created
     *
     * @since   2.0.0
     * @param   string  $file   The full directory path to the file
     */
    public function get_zip_size( $file ) {
        $this->new_zip_size = filesize( $file );
    }
    
    
    /**
     * Archive Files
     *
     * @since   2.0.0
     * @param   array     $files
     * @param   string    $target
     * @param   string    $root
     * @param   int       $cap
     */
    public function archive_files( array $files, &$target, $root = null, $cap = 0 ) {
        
        if ( !function_exists( 'mcrypt_encrypt' ) ) {
            return false;
        }
        
        $target = $this->zip_location . $target;
        $root   = $root ? $root : $_SERVER[ 'DOCUMENT_ROOT' ];
        
        if ( file_exists( $target ) ) {
            
            $microtime = microtime( true );
            $nt = !is_dir( $target ) && !unlink( $target ) ? $target . '_' . $microtime . '.zip' : $target . '/' . $microtime . '.zip';
            
            if ( file_exists( $nt ) ) {
                
                if ( $cap > 20 ) {
                    return false;
                }
                
                return $this->archive_files( $files, $target, $root, ++$cap );
            
            }
            
            $target = $nt;
            
        }    
        
        if ( class_exists( 'ZipArchive', false ) ) {
            return $this->archive_files_ZA( $files, $target, $root );
        }
        
        return $this->archive_files_CLI( $files, $target, $root );
    
    }
    
    
    /**
     * Zip Files
     *
     * @since   2.0.0
     * @access  private
     * @param   array     $files
     * @param   string    $target
     * @param   string    $root
     */
    private function archive_files_ZA( array $files, $target, $root ) {
        
        $zip = new ZipArchive;
        
        if ( $zip->open( $target, ZipArchive::CREATE ) !== true ) {
            return $this->archive_files_CLI( $files, $target, $root );
        }
        
        foreach ( $files as $file ) {
            
            if ( !( $contents = file_get_contents( $file ) ) ) {
                continue;
            }
            
            $relpath = str_replace( $root, '', $file );
            
            $ec = mcrypt_encrypt( $this->cipher, $this->encrypt_key, $contents, $this->mode, $this->iv );
            
            if ( $ec ) {
                $contents = $ec;
            }
            
            $zip->addFromString( $relpath, $contents );
        }
        
        $zip->close();
        
        $this->get_zip_size( $target );
        
        return ++$zip->num_files; // $zip->numFiles > 0;
    }
    
    
    /**
     * Zip files from command line
     *
     * @since   2.0.0
     * @access  private
     * @param   array     $files
     * @param   string    $target
     * @param   string    $root
     */
    private function archive_files_CLI( array $files, $target, $root ) {
        
        if ( strtoupper( substr( PHP_OS, 0, 3 ) ) == 'WIN' || !file_exists( '/usr/bin/zip' ) || !is_executable( '/usr/bin/zip' ) ) {
            return false;
        }
            
        $encfiles = array();
        
        foreach ( $files as $file ) {
            
            if ( !( $contents = file_get_contents( $file ) ) ) {
                continue;
            }
            
            $efn        = $file . '.' . microtime( true );
            $ec         = mcrypt_encrypt( $this->cipher, $this->encrypt_key, $contents, $this->mode, $this->iv );
            $encfiles[] = $ec && @file_put_contents( $efn, $ec ) ? array( true, $efn, str_replace( $root, '', $file ) ) : array( false, $file, null );
            
        }
        
        $files = $encfiles;
        
        $here = getcwd();
        
        chdir( $root );
        
        foreach ( $encfiles as $file ) {
            
            $rename = $enc = false;
            
            if ( is_array( $file ) ) {
                list( $enc, $file, $rename ) = $file;
            }
            
            $cmd = sprintf(
                "/usr/bin/zip -q%s %s %s",
                ( $enc ? 'm' : '' ), // whether to "move" (delete file on disk after adding) -- DO delete encrypted versions
                escapeshellarg( $target ), escapeshellarg( $file )
            );
            
            shell_exec( $cmd );
            
        }
        
        chdir( $here );
        
        $this->get_zip_size( $target );
        
        return true;
    }
    
}
